@@ -436,9 +436,13 @@ class DryRunRunner(BaseRunner):
 RUNNERS_REGISTRY_PYTHON_CLASS['dry-run'] = DryRunRunner
 
 
-class ExecRunner(BaseRunner):
+class ExecTestRunner(BaseRunner):
     """
-    Runner for standalone executables with or without arguments
+    Runner for standalone executables treated as tests
+
+    This is similar in concept to the Avocado "SIMPLE" test type, in which an
+    executable returning 0 means that a test passed, and anything else means
+    that a test failed.
 
     Runnable attributes usage:
 
@@ -453,8 +457,21 @@ class ExecRunner(BaseRunner):
 
     def _process_final_status(self, process,
                               stdout=None, stderr=None):  # pylint: disable=W0613
-        return self.prepare_status('finished',
-                                   {'returncode': process.returncode})
+        # Since Runners are standalone, and could be executed on a remote
+        # machine in an "isolated" way, there is no way to assume a default
+        # value, at this moment.
+        skip_codes = self.runnable.config.get('runner.exectest.exitcodes.skip',
+                                              [])
+        final_status = {}
+        if process.returncode in skip_codes:
+            final_status['result'] = 'skip'
+        elif process.returncode == 0:
+            final_status['result'] = 'pass'
+        else:
+            final_status['result'] = 'fail'
+
+        final_status['returncode'] = process.returncode
+        return self.prepare_status('finished', final_status)
 
     def _create_params(self):
         """Create params for the test"""
@@ -520,39 +537,6 @@ class ExecRunner(BaseRunner):
         yield self._process_final_status(process, stdout, stderr)
 
 
-RUNNERS_REGISTRY_PYTHON_CLASS['exec'] = ExecRunner
-
-
-class ExecTestRunner(ExecRunner):
-    """
-    Runner for standalone executables treated as tests
-
-    This is similar in concept to the Avocado "SIMPLE" test type, in which an
-    executable returning 0 means that a test passed, and anything else means
-    that a test failed.
-
-    Runnable attributes usage is identical to :class:`ExecRunner`
-    """
-
-    def _process_final_status(self, process,
-                              stdout=None, stderr=None):  # pylint: disable=W0613
-        # Since Runners are standalone, and could be executed on a remote
-        # machine in an "isolated" way, there is no way to assume a default
-        # value, at this moment.
-        skip_codes = self.runnable.config.get('runner.exectest.exitcodes.skip',
-                                              [])
-        final_status = {}
-        if process.returncode in skip_codes:
-            final_status['result'] = 'skip'
-        elif process.returncode == 0:
-            final_status['result'] = 'pass'
-        else:
-            final_status['result'] = 'fail'
-
-        final_status['returncode'] = process.returncode
-        return self.prepare_status('finished', final_status)
-
-
 RUNNERS_REGISTRY_PYTHON_CLASS['exec-test'] = ExecTestRunner
 
 
@@ -577,6 +561,14 @@ class PythonUnittestRunner(BaseRunner):
 
     @property
     def unittest(self):
+        """Returns the unittest part of an uri as tuple.
+
+        Ex:
+
+        uri = './avocado.dev/selftests/.data/unittests/test.py:Class.test_foo'
+        It will return ("test", "Class", "test_foo")
+        """
+
         uri = self.runnable.uri
         if ':' in uri:
             module, class_method = uri.rsplit(':', 1)
@@ -585,32 +577,24 @@ class PythonUnittestRunner(BaseRunner):
 
         if module.endswith('.py'):
             module = module[:-3]
-        if module.startswith(os.path.curdir):
-            module = module[1:]
-            if module.startswith(os.path.sep):
-                module = module[1:]
-        module = module.replace(os.path.sep, ".")
+        module = module.rsplit(os.path.sep, 1)[-1]
+
         klass, method = class_method.rsplit('.', maxsplit=1)
         return module, klass, method
 
-    @property
-    def unittest_name(self):
-        """Convert a test reference (uri) to an unittest name reference."""
-        unittest = self.unittest
-        if not unittest:
-            return None
-        return "{}.{}.{}".format(*unittest)
-
     @property
     def module_path(self):
-        unittest = self.unittest
-        if not unittest:
+        """Path where the module is located.
+
+        Ex:
+        uri = './avocado.dev/selftests/.data/unittests/test.py:Class.test_foo'
+        It will return './avocado.dev/selftests/.data/unittests/'
+        """
+        uri = self.runnable.uri
+        if not uri:
             return None
-        module, _, _ = unittest
-        path = module.replace('.', os.path.sep)
-        # This will fix adding support to hidden directories
-        path = path.replace('//', '/.')
-        return os.path.dirname(path)
+        module_path = uri.rsplit(':', 1)[0]
+        return os.path.dirname(module_path)
 
     @property
     def module_class_method(self):
@@ -623,11 +607,7 @@ class PythonUnittestRunner(BaseRunner):
         if not unittest:
             return None
 
-        full_module, klass, method = unittest
-        # Lets split the full_module and get the module_path + module it self
-        # We care here only about the module (without the path)
-        _, module = full_module.rsplit(".", maxsplit=1)
-        return ".".join((module, klass, method))
+        return ".".join(unittest)
 
     @classmethod
     def _run_unittest(cls, module_path, module_class_method, queue):
@@ -647,12 +627,16 @@ class PythonUnittestRunner(BaseRunner):
         runner = TextTestRunner(stream=stream, verbosity=0)
         unittest_result = runner.run(suite)
 
+        unittest_result_entries = None
         if len(unittest_result.errors) > 0:
             result = 'error'
+            unittest_result_entries = unittest_result.errors
         elif len(unittest_result.failures) > 0:
             result = 'fail'
+            unittest_result_entries = unittest_result.failures
         elif len(unittest_result.skipped) > 0:
             result = 'skip'
+            unittest_result_entries = unittest_result.skipped
         else:
             result = 'pass'
 
@@ -660,11 +644,18 @@ class PythonUnittestRunner(BaseRunner):
         output = {'status': 'finished',
                   'result': result,
                   'output': stream.read()}
+
+        if unittest_result_entries is not None:
+            last_entry = unittest_result_entries[-1]
+            lines = last_entry[1].splitlines()
+            fail_reason = lines[-1]
+            output['fail_reason'] = fail_reason
+
         stream.close()
         queue.put(output)
 
     def run(self):
-        if not self.unittest_name:
+        if not self.module_class_method:
             error_msg = ("Invalid URI: could not be converted to an unittest "
                          "dotted name.")
             yield self.prepare_status('finished', {'result': 'error',
