@@ -15,8 +15,6 @@
 
 import abc
 
-from .resolver import ResolverMixin
-
 
 class Plugin(abc.ABC):
     """Base for all plugins."""
@@ -218,6 +216,14 @@ class Varianter(Plugin):
         """
 
 
+class ResolverMixin:
+    """Common utilities for Resolver implementations."""
+
+    def __init__(self, config=None):
+        from avocado.core.settings import settings
+        self.config = config or settings.as_dict()
+
+
 class Resolver(Plugin, ResolverMixin):
     """Base plugin interface for resolving test references into resolutions."""
 
