@@ -3,6 +3,7 @@ import sys
 import time
 
 from ... import output
+from ...streams import BUILTIN_STREAMS
 
 
 class GenericMessage:
@@ -122,6 +123,11 @@ class WhiteboardMessage(GenericRunningMessage):
     message_type = 'whiteboard'
 
 
+class OutputMessage(GenericRunningMessage):
+    """Creates output message with all necessary information."""
+    message_type = 'output'
+
+
 class FileMessage(GenericRunningMessage):
     """Creates file message with  all necessary information."""
     message_type = 'file'
@@ -135,6 +141,7 @@ _supported_types = {LogMessage.message_type: LogMessage,
                     StdoutMessage.message_type: StdoutMessage,
                     StderrMessage.message_type: StderrMessage,
                     WhiteboardMessage.message_type: WhiteboardMessage,
+                    OutputMessage.message_type: OutputMessage,
                     FileMessage.message_type: FileMessage}
 
 
@@ -215,3 +222,13 @@ def start_logging(config, queue):
 
     sys.stdout = StreamToQueue(queue, "stdout")
     sys.stderr = StreamToQueue(queue, "stderr")
+
+    # output custom test loggers
+    enabled_loggers = config.get('core.show') or set(["app"])
+    output_handler = RunnerLogHandler(queue, 'output')
+    output_handler.setFormatter(logging.Formatter(fmt='%(name)s: %(message)s'))
+    for user_stream in [user_streams for user_streams in enabled_loggers
+                        if user_streams not in BUILTIN_STREAMS]:
+        custom_logger = logging.getLogger(user_stream)
+        custom_logger.addHandler(output_handler)
+        custom_logger.setLevel(log_level)
