@@ -24,6 +24,11 @@ def get_methods_info(statement_body, class_tags, class_requirements):
         if not (isinstance(st, (ast.FunctionDef, ast.AsyncFunctionDef))):
             continue
 
+        decorators = getattr(st, 'decorator_list', [])
+        decorator_names = [getattr(_, 'id', None) for _ in decorators]
+        if 'property' in decorator_names:
+            continue
+
         if not st.name.startswith('test'):
             continue
 
@@ -215,7 +220,7 @@ def _examine_class(target_module, target_class, determine_match, path,
         docstring = ast.get_docstring(klass)
 
         if match is False:
-            match = determine_match(module, klass, docstring)
+            match = module.is_matching_klass(klass)
 
         info = get_methods_info(klass.body,
                                 get_docstring_directives_tags(docstring),
