@@ -31,8 +31,7 @@ class FetchAsset(unittest.TestCase):
         Setup configuration file and folders
         """
         warnings.simplefilter("ignore", ResourceWarning)
-        self.base_dir, self.mapping, self.config_file = get_temporary_config(
-            __name__, self, 'setUp')
+        self.base_dir, self.mapping, self.config_file = get_temporary_config(self)
 
         self.asset_dir = os.path.join(self.mapping['cache_dir'],
                                       'by_location',
@@ -62,9 +61,11 @@ class FetchAsset(unittest.TestCase):
         test_file.close()
 
         expected_rc = exit_codes.AVOCADO_ALL_OK
-        cmd_line = "%s --config %s run %s " % (AVOCADO,
-                                               self.config_file.name,
-                                               test_file.name)
+        cmd_line = ("%s --config %s run "
+                    "--test-runner=runner "
+                    "%s" % (AVOCADO,
+                            self.config_file.name,
+                            test_file.name))
         result = process.run(cmd_line)
         os.remove(localpath)
         self.assertEqual(expected_rc, result.exit_status)
@@ -93,9 +94,11 @@ class FetchAsset(unittest.TestCase):
         expected_rc = exit_codes.AVOCADO_TESTS_FAIL
         expected_stdout = "not found in the cache"
 
-        cmd_line = "%s --config %s run %s " % (AVOCADO,
-                                               self.config_file.name,
-                                               test_file.name)
+        cmd_line = ("%s --config %s run "
+                    "--test-runner=runner "
+                    "%s" % (AVOCADO,
+                            self.config_file.name,
+                            test_file.name))
 
         result = process.run(cmd_line, ignore_status=True)
         self.assertEqual(expected_rc, result.exit_status)
@@ -124,9 +127,11 @@ class FetchAsset(unittest.TestCase):
         expected_rc = exit_codes.AVOCADO_ALL_OK
         expected_stdout = "Missing asset"
 
-        cmd_line = "%s --config %s run %s " % (AVOCADO,
-                                               self.config_file.name,
-                                               test_file.name)
+        cmd_line = ("%s --config %s run "
+                    "--test-runner=runner "
+                    "%s" % (AVOCADO,
+                            self.config_file.name,
+                            test_file.name))
 
         result = process.run(cmd_line, ignore_status=True)
         self.assertEqual(expected_rc, result.exit_status)
@@ -154,9 +159,11 @@ class FetchAsset(unittest.TestCase):
         expected_rc = exit_codes.AVOCADO_ALL_OK
         expected_stdout = "Missing asset"
 
-        cmd_line = "%s --config %s run %s " % (AVOCADO,
-                                               self.config_file.name,
-                                               test_file.name)
+        cmd_line = ("%s --config %s run "
+                    "--test-runner=runner "
+                    "%s " % (AVOCADO,
+                             self.config_file.name,
+                             test_file.name))
 
         result = process.run(cmd_line, ignore_status=True)
         self.assertEqual(expected_rc, result.exit_status)
